--- multiqc/multiqc.py.orig	2023-05-11 13:19:10 UTC
+++ multiqc/multiqc.py
@@ -24,7 +24,13 @@ from urllib.request import urlopen
 
 import jinja2
 import rich
-import rich_click as click
+if 'LC_ALL' in os.environ and 'LANG' in os.environ:
+    import rich_click as click
+else:
+    print('multiqc: LC_ALL and LANG must be set to a UTF-8 character set')
+    print('in your environment in order for the click module to function.')
+    print('E.g. export LC_ALL=en_US.UTF-8 or setenv LC_ALL en_US.UTF-8')
+    sys.exit()
 from rich.syntax import Syntax
 
 from .plots import table



- workaround for https://github.com/dofuuz/python-soxr/issues/25

--- setup.py.orig	2024-01-24 02:08:37 UTC
+++ setup.py
@@ -122,7 +122,8 @@ if '-arm' in platform:
 
 platform = sysconfig.get_platform()
 if '-arm' in platform:
-    compile_args.append('-mfpu=neon')
+    #compile_args.append('-mfpu=neon')
+    pass
 elif '-i686' in platform:
     compile_args.append('-msse')
 



--- setup.py.orig	2024-02-24 14:39:02 UTC
+++ setup.py
@@ -70,7 +70,7 @@ def main():
 
     if not clang:
         try:
-            gcc_version_check = subprocess.check_output( ["gcc", "--version"], universal_newlines=True)
+            gcc_version_check = subprocess.check_output( ["cc", "--version"], universal_newlines=True)
             if gcc_version_check.find("clang") != -1:
                 clang = True
             else:
